#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.paragraph.interfaces import IParagraphFactory
from pyams_content.component.paragraph.interfaces.header import IHeaderParagraph
from pyams_content.features.checker.interfaces import IContentChecker, MISSING_VALUE, MISSING_LANG_VALUE
from pyams_i18n.interfaces import II18n, II18nManager, INegotiator

# import packages
from pyams_content.component.paragraph import BaseParagraph, BaseParagraphContentChecker
from pyams_utils.adapter import adapter_config
from pyams_utils.registry import utility_config, get_utility
from pyams_utils.text import get_text_start
from pyams_utils.traversing import get_parent
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty

from pyams_content import _


@implementer(IHeaderParagraph)
class HeaderParagraph(BaseParagraph):
    """Header paragraph"""

    icon_class = 'fa-header'
    icon_hint = _("Header")

    @property
    def title(self):
        header = II18n(self).query_attribute('header')
        return get_text_start(header, 50, 10)

    header = FieldProperty(IHeaderParagraph['header'])


@utility_config(name='Header', provides=IParagraphFactory)
class HTMLParagraphFactory(object):
    """HTML paragraph factory"""

    name = _("Header paragraph")
    content_type = HeaderParagraph


@adapter_config(context=IHeaderParagraph, provides=IContentChecker)
class HeaderParagraphContentChecker(BaseParagraphContentChecker):
    """Header paragraph content checker"""

    def inner_check(self, request):
        output = []
        translate = request.localizer.translate
        manager = get_parent(self.context, II18nManager)
        if manager is not None:
            langs = manager.get_languages()
        else:
            negotiator = get_utility(INegotiator)
            langs = (negotiator.server_language, )
        i18n = II18n(self.context)
        for lang in langs:
            value = i18n.get_attribute('header', lang, request)
            if not value:
                field_title = translate(IHeaderParagraph['header'].title)
                if len(langs) == 1:
                    output.append(translate(MISSING_VALUE).format(field=field_title))
                else:
                    output.append(translate(MISSING_LANG_VALUE).format(field=field_title, lang=lang))
        return output
